The implemetation of the Reaper class makes use of two class
unions in order to deal with cases when we are unable to fit a
model.
The number or miss class union can either hold a
numeric vector or a logical vector.
The fit or miss class union
can hold either a fitted movMF object or a logical vector.